@@ -192,6 +192,9 @@ func main() {
 	maybeLogProgress("binfmt")
 	s.add(mapTags(newBinfmtChecker(tags).check(pkgFiles)))
 
+	maybeLogProgress("system ids")
+	s.add(mapTags(newSystemIDChecker(tags).check(pkgFiles)))
+
 	maybeLogProgress(fmt.Sprintf("%d files for elf-related", totalFiles))
 	s.add(mapTags(newElfChecker(tags, ids).check(pkgFiles)))
 
